@@ -24,6 +24,7 @@
 #endif
 
 #define _GNU_SOURCE
+#include <errno.h>
 #include <sys/mman.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -32,9 +33,13 @@
 #include <unistd.h>
 #include <string.h>
 #include <limits.h>
+#include <sys/stat.h>
 
 #include "connman.h"
 
+#define MODE		(S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | \
+			S_IXGRP | S_IROTH | S_IXOTH)
+
 #ifdef TEMP_FAILURE_RETRY
 #define TFR TEMP_FAILURE_RETRY
 #else
@@ -214,6 +219,9 @@ static void stats_free(gpointer user_data)
 {
 	struct stats_file *file = user_data;
 
+	if (!file)
+		return;
+
 	msync(file->addr, file->len, MS_SYNC);
 
 	munmap(file->addr, file->len);
@@ -222,18 +230,17 @@ static void stats_free(gpointer user_data)
 	TFR(close(file->fd));
 	file->fd = -1;
 
-	if (file->history_name != NULL) {
+	if (file->history_name) {
 		g_free(file->history_name);
 		file->history_name = NULL;
 	}
 
-	if (file->name != NULL) {
+	if (file->name) {
 		g_free(file->name);
 		file->name = NULL;
 	}
 
-	if (file != NULL)
-		g_free(file);
+	g_free(file);
 }
 
 static void update_first(struct stats_file *file)
@@ -275,6 +282,9 @@ static int stats_file_remap(struct stats_file *file, size_t size)
 	void *addr;
 	int err;
 
+	DBG("file %p size %zu addr %p len %zu", file, size, file->addr,
+		file->len);
+
 	page_size = sysconf(_SC_PAGESIZE);
 	new_size = (size + page_size - 1) & ~(page_size - 1);
 
@@ -285,12 +295,13 @@ static int stats_file_remap(struct stats_file *file, size_t size)
 		return -errno;
 	}
 
-	if (file->addr == NULL) {
+	if (!file->addr) {
 		/*
 		 * Though the buffer is not shared between processes, we still
-		 * have to take MAP_SHARED because MAP_PRIVATE does not guarantee
-		 * that writes will hit the file eventually. For more details
-		 * please read the mmap man pages.
+		 * have to take MAP_SHARED because MAP_PRIVATE does not
+		 * guarantee that writes will hit the file without an explicit
+		 * call to munmap or msync. For more details please read the
+		 * mmap man pages.
 		 */
 		addr = mmap(NULL, new_size, PROT_READ | PROT_WRITE,
 				MAP_SHARED, file->fd, 0);
@@ -301,6 +312,11 @@ static int stats_file_remap(struct stats_file *file, size_t size)
 	if (addr == MAP_FAILED) {
 		connman_error("mmap error %s for %s",
 				strerror(errno), file->name);
+		if (errno == EINVAL) {
+			connman_error("%s might be on a file system, such as "
+					"JFFS2, that does not allow shared "
+					"writable mappings.", file->name);
+		}
 		return -errno;
 	}
 
@@ -315,13 +331,16 @@ static int stats_file_remap(struct stats_file *file, size_t size)
 static int stats_open(struct stats_file *file,
 			const char *name)
 {
+	DBG("file %p name %s", file, name);
+
 	file->name = g_strdup(name);
 
-	file->fd = TFR(open(file->name, O_RDWR | O_CREAT, 0644));
+	file->fd = TFR(open(file->name, O_RDWR | O_CREAT | O_CLOEXEC, 0644));
 	if (file->fd < 0) {
 		connman_error("open error %s for %s",
 				strerror(errno), file->name);
 		g_free(file->name);
+		file->name = NULL;
 		return -errno;
 	}
 
@@ -330,13 +349,14 @@ static int stats_open(struct stats_file *file,
 
 static int stats_open_temp(struct stats_file *file)
 {
-	file->name = g_strdup_printf("%s/stats/stats.XXXXXX.tmp",
+	file->name = g_strdup_printf("%s/stats.XXXXXX.tmp",
 					STORAGEDIR);
 	file->fd = g_mkstemp_full(file->name, O_RDWR | O_CREAT, 0644);
 	if (file->fd < 0) {
 		connman_error("create tempory file error %s for %s",
 				strerror(errno), file->name);
 		g_free(file->name);
+		file->name = NULL;
 		return -errno;
 	}
 
@@ -350,6 +370,8 @@ static int stats_file_setup(struct stats_file *file)
 	size_t size = 0;
 	int err;
 
+	DBG("file %p fd %d name %s", file, file->fd, file->name);
+
 	err = fstat(file->fd, &st);
 	if (err < 0) {
 		connman_error("fstat error %s for %s\n",
@@ -357,6 +379,7 @@ static int stats_file_setup(struct stats_file *file)
 
 		TFR(close(file->fd));
 		g_free(file->name);
+		file->name = NULL;
 
 		return -errno;
 	}
@@ -371,6 +394,7 @@ static int stats_file_setup(struct stats_file *file)
 	if (err < 0) {
 		TFR(close(file->fd));
 		g_free(file->name);
+		file->name = NULL;
 
 		return err;
 	}
@@ -448,18 +472,18 @@ static struct stats_record *process_file(struct stats_iter *iter,
 	home = NULL;
 	roaming = NULL;
 
-	if (cur == NULL)
+	if (!cur)
 		cur = get_next_record(iter);
 	next = get_next_record(iter);
 
-	while (next != NULL) {
+	while (next) {
 		GDate date_cur;
 		GDate date_next;
 		int append;
 
 		append = FALSE;
 
-		if (cur->roaming == TRUE)
+		if (cur->roaming)
 			roaming = cur;
 		else
 			home = cur;
@@ -490,13 +514,13 @@ static struct stats_record *process_file(struct stats_iter *iter,
 				append = TRUE;
 		}
 
-		if (append == TRUE) {
-			if (home != NULL) {
+		if (append) {
+			if (home) {
 				append_record(temp_file, home);
 				home = NULL;
 			}
 
-			if (roaming != NULL) {
+			if (roaming) {
 				append_record(temp_file, roaming);
 				roaming = NULL;
 			}
@@ -538,7 +562,7 @@ static int summarize(struct stats_file *data_file,
 	/* Now process history file */
 	cur = NULL;
 
-	if (history_file != NULL) {
+	if (history_file) {
 		history_iter.file = history_file;
 		history_iter.begin = get_iterator_begin(history_iter.file);
 		history_iter.end = get_iterator_end(history_iter.file);
@@ -558,9 +582,9 @@ static int summarize(struct stats_file *data_file,
 	 * Ensure date_file records are newer than the history_file
 	 * record
 	 */
-	if (cur != NULL) {
+	if (cur) {
 		next = get_next_record(&data_iter);
-		while (next != NULL && cur->ts > next->ts)
+		while (next && cur->ts > next->ts)
 			next = get_next_record(&data_iter);
 	}
 
@@ -569,7 +593,7 @@ static int summarize(struct stats_file *data_file,
 				&date_change_step_size,
 				data_file->account_period_offset);
 
-	if (cur != NULL)
+	if (cur)
 		append_record(temp_file, cur);
 
 	return 0;
@@ -586,6 +610,7 @@ static void stats_file_cleanup(struct stats_file *file)
 {
 	file->fd = -1;
 	g_free(file->name);
+	file->name = NULL;
 }
 
 static int stats_file_close_swap(struct stats_file *history_file,
@@ -646,15 +671,15 @@ static int stats_file_history_update(struct stats_file *data_file)
 int __connman_stats_service_register(struct connman_service *service)
 {
 	struct stats_file *file;
-	char *name;
+	char *name, *dir;
 	int err;
 
 	DBG("service %p", service);
 
 	file = g_hash_table_lookup(stats_hash, service);
-	if (file == NULL) {
+	if (!file) {
 		file = g_try_new0(struct stats_file, 1);
-		if (file == NULL)
+		if (!file)
 			return -ENOMEM;
 
 		g_hash_table_insert(stats_hash, service, file);
@@ -662,9 +687,26 @@ int __connman_stats_service_register(struct connman_service *service)
 		return -EALREADY;
 	}
 
-	name = g_strdup_printf("%s/stats/%s.data", STORAGEDIR,
+	dir = g_strdup_printf("%s/%s", STORAGEDIR,
 				__connman_service_get_ident(service));
-	file->history_name = g_strdup_printf("%s/stats/%s.history", STORAGEDIR,
+
+	/* If the dir doesn't exist, create it */
+	if (!g_file_test(dir, G_FILE_TEST_IS_DIR)) {
+		if (mkdir(dir, MODE) < 0) {
+			if (errno != EEXIST) {
+				g_free(dir);
+
+				err = -errno;
+				goto err;
+			}
+		}
+	}
+
+	g_free(dir);
+
+	name = g_strdup_printf("%s/%s/data", STORAGEDIR,
+				__connman_service_get_ident(service));
+	file->history_name = g_strdup_printf("%s/%s/history", STORAGEDIR,
 				__connman_service_get_ident(service));
 
 	/* TODO: Use a global config file instead of hard coded value. */
@@ -695,7 +737,7 @@ void __connman_stats_service_unregister(struct connman_service *service)
 }
 
 int  __connman_stats_update(struct connman_service *service,
-				connman_bool_t roaming,
+				bool roaming,
 				struct connman_stats_data *data)
 {
 	struct stats_file *file;
@@ -703,7 +745,7 @@ int  __connman_stats_update(struct connman_service *service,
 	int err;
 
 	file = g_hash_table_lookup(stats_hash, service);
-	if (file == NULL)
+	if (!file)
 		return -EEXIST;
 
 	if (file->len < file->max_len &&
@@ -730,7 +772,7 @@ int  __connman_stats_update(struct connman_service *service,
 	next->roaming = roaming;
 	memcpy(&next->data, data, sizeof(struct connman_stats_data));
 
-	if (roaming != TRUE)
+	if (!roaming)
 		set_home(file, next);
 	else
 		set_roaming(file, next);
@@ -741,22 +783,22 @@ int  __connman_stats_update(struct connman_service *service,
 }
 
 int __connman_stats_get(struct connman_service *service,
-				connman_bool_t roaming,
+				bool roaming,
 				struct connman_stats_data *data)
 {
 	struct stats_file *file;
 	struct stats_record *rec;
 
 	file = g_hash_table_lookup(stats_hash, service);
-	if (file == NULL)
+	if (!file)
 		return -EEXIST;
 
-	if (roaming != TRUE)
+	if (!roaming)
 		rec = file->home;
 	else
 		rec = file->roaming;
 
-	if (rec != NULL) {
+	if (rec) {
 		memcpy(data, &rec->data,
 			sizeof(struct connman_stats_data));
 	}
