@@ -34,7 +34,7 @@
 #define STATUS_URL_IPV6  "http://ipv6.connman.net/online/status.html"
 
 struct connman_wispr_message {
-	gboolean has_error;
+	bool has_error;
 	const char *current_element;
 	int message_type;
 	int response_code;
@@ -92,7 +92,7 @@ struct connman_wispr_portal {
 	struct connman_wispr_portal_context *ipv6_context;
 };
 
-static gboolean wispr_portal_web_result(GWebResult *result, gpointer user_data);
+static bool wispr_portal_web_result(GWebResult *result, gpointer user_data);
 
 static GHashTable *wispr_portal_list = NULL;
 
@@ -100,7 +100,7 @@ static void connman_wispr_message_init(struct connman_wispr_message *msg)
 {
 	DBG("");
 
-	msg->has_error = FALSE;
+	msg->has_error = false;
 	msg->current_element = NULL;
 
 	msg->message_type = -1;
@@ -127,13 +127,13 @@ static void connman_wispr_message_init(struct connman_wispr_message *msg)
 
 static void free_wispr_routes(struct connman_wispr_portal_context *wp_context)
 {
-	while (wp_context->route_list != NULL) {
+	while (wp_context->route_list) {
 		struct wispr_route *route = wp_context->route_list->data;
 
 		DBG("free route to %s if %d type %d", route->address,
 				route->if_index, wp_context->type);
 
-		switch(wp_context->type) {
+		switch (wp_context->type) {
 		case CONNMAN_IPCONFIG_TYPE_IPV4:
 			connman_inet_del_host_route(route->if_index,
 					route->address);
@@ -155,14 +155,15 @@ static void free_wispr_routes(struct connman_wispr_portal_context *wp_context)
 	}
 }
 
-static void free_connman_wispr_portal_context(struct connman_wispr_portal_context *wp_context)
+static void free_connman_wispr_portal_context(
+		struct connman_wispr_portal_context *wp_context)
 {
 	DBG("context %p", wp_context);
 
-	if (wp_context == NULL)
+	if (!wp_context)
 		return;
 
-	if (wp_context->wispr_portal != NULL) {
+	if (wp_context->wispr_portal) {
 		if (wp_context->wispr_portal->ipv4_context == wp_context)
 			wp_context->wispr_portal->ipv4_context = NULL;
 
@@ -179,12 +180,12 @@ static void free_connman_wispr_portal_context(struct connman_wispr_portal_contex
 	if (wp_context->timeout > 0)
 		g_source_remove(wp_context->timeout);
 
-	if (wp_context->web != NULL)
+	if (wp_context->web)
 		g_web_unref(wp_context->web);
 
 	g_free(wp_context->redirect_url);
 
-	if (wp_context->wispr_parser != NULL)
+	if (wp_context->wispr_parser)
 		g_web_parser_unref(wp_context->wispr_parser);
 
 	connman_wispr_message_init(&wp_context->wispr_msg);
@@ -209,7 +210,7 @@ static void free_connman_wispr_portal(gpointer data)
 
 	DBG("");
 
-	if (wispr_portal == NULL)
+	if (!wispr_portal)
 		return;
 
 	free_connman_wispr_portal_context(wispr_portal->ipv4_context);
@@ -326,12 +327,11 @@ static void xml_wispr_text_handler(GMarkupParseContext *context,
 	struct connman_wispr_message *msg = user_data;
 	int i;
 
-	if (msg->current_element == NULL)
+	if (!msg->current_element)
 		return;
 
 	for (i = 0; wispr_element_map[i].str; i++) {
-		if (g_str_equal(wispr_element_map[i].str,
-					msg->current_element) == FALSE)
+		if (!g_str_equal(wispr_element_map[i].str, msg->current_element))
 			continue;
 
 		switch (wispr_element_map[i].element) {
@@ -380,7 +380,7 @@ static void xml_wispr_error_handler(GMarkupParseContext *context,
 {
 	struct connman_wispr_message *msg = user_data;
 
-	msg->has_error = TRUE;
+	msg->has_error = true;
 }
 
 static const GMarkupParser xml_wispr_parser_handlers = {
@@ -395,7 +395,7 @@ static void xml_wispr_parser_callback(const char *str, gpointer user_data)
 {
 	struct connman_wispr_portal_context *wp_context = user_data;
 	GMarkupParseContext *parser_context = NULL;
-	gboolean result;
+	bool result;
 
 	DBG("");
 
@@ -405,7 +405,7 @@ static void xml_wispr_parser_callback(const char *str, gpointer user_data)
 
 	result = g_markup_parse_context_parse(parser_context,
 					str, strlen(str), NULL);
-	if (result == TRUE)
+	if (result)
 		g_markup_parse_context_end_parse(parser_context, NULL);
 
 	g_markup_parse_context_free(parser_context);
@@ -434,19 +434,19 @@ static void portal_manage_status(GWebResult *result,
 
 	/* We currently don't do anything with this info */
 	if (g_web_result_get_header(result, "X-ConnMan-Client-IP",
-				&str) == TRUE)
+				&str))
 		connman_info("Client-IP: %s", str);
 
 	if (g_web_result_get_header(result, "X-ConnMan-Client-Country",
-				&str) == TRUE)
+				&str))
 		connman_info("Client-Country: %s", str);
 
 	if (g_web_result_get_header(result, "X-ConnMan-Client-Region",
-				&str) == TRUE)
+				&str))
 		connman_info("Client-Region: %s", str);
 
 	if (g_web_result_get_header(result, "X-ConnMan-Client-Timezone",
-				&str) == TRUE)
+				&str))
 		connman_info("Client-Timezone: %s", str);
 
 	free_connman_wispr_portal_context(wp_context);
@@ -455,7 +455,7 @@ static void portal_manage_status(GWebResult *result,
 					CONNMAN_SERVICE_STATE_ONLINE, type);
 }
 
-static gboolean wispr_route_request(const char *address, int ai_family,
+static bool wispr_route_request(const char *address, int ai_family,
 		int if_index, gpointer user_data)
 {
 	int result = -1;
@@ -468,16 +468,16 @@ static gboolean wispr_route_request(const char *address, int ai_family,
 
 	DBG("address %s if %d gw %s", address, if_index, gateway);
 
-	if (gateway == NULL)
-		return FALSE;
+	if (!gateway)
+		return false;
 
 	route = g_try_new0(struct wispr_route, 1);
 	if (route == 0) {
 		DBG("could not create struct");
-		return FALSE;
+		return false;
 	}
 
-	switch(wp_context->type) {
+	switch (wp_context->type) {
 	case CONNMAN_IPCONFIG_TYPE_IPV4:
 		result = connman_inet_add_host_route(if_index, address,
 				gateway);
@@ -492,17 +492,18 @@ static gboolean wispr_route_request(const char *address, int ai_family,
 
 	if (result < 0) {
 		g_free(route);
-		return FALSE;
+		return false;
 	}
 
 	route->address = g_strdup(address);
 	route->if_index = if_index;
 	wp_context->route_list = g_slist_prepend(wp_context->route_list, route);
 
-	return TRUE;
+	return true;
 }
 
-static void wispr_portal_request_portal(struct connman_wispr_portal_context *wp_context)
+static void wispr_portal_request_portal(
+		struct connman_wispr_portal_context *wp_context)
 {
 	DBG("");
 
@@ -516,7 +517,7 @@ static void wispr_portal_request_portal(struct connman_wispr_portal_context *wp_
 		wispr_portal_error(wp_context);
 }
 
-static gboolean wispr_input(const guint8 **data, gsize *length,
+static bool wispr_input(const guint8 **data, gsize *length,
 						gpointer user_data)
 {
 	struct connman_wispr_portal_context *wp_context = user_data;
@@ -544,21 +545,21 @@ static gboolean wispr_input(const guint8 **data, gsize *length,
 	*data = (guint8 *) wp_context->wispr_formdata;
 	*length = count;
 
-	return FALSE;
+	return false;
 }
 
 static void wispr_portal_browser_reply_cb(struct connman_service *service,
-					connman_bool_t authentication_done,
+					bool authentication_done,
 					const char *error, void *user_data)
 {
 	struct connman_wispr_portal_context *wp_context = user_data;
 
 	DBG("");
 
-	if (service == NULL || wp_context == NULL)
+	if (!service || !wp_context)
 		return;
 
-	if (authentication_done == FALSE) {
+	if (!authentication_done) {
 		wispr_portal_error(wp_context);
 		free_wispr_routes(wp_context);
 		return;
@@ -569,17 +570,17 @@ static void wispr_portal_browser_reply_cb(struct connman_service *service,
 }
 
 static void wispr_portal_request_wispr_login(struct connman_service *service,
-				connman_bool_t success,
+				bool success,
 				const char *ssid, int ssid_len,
 				const char *username, const char *password,
-				gboolean wps, const char *wpspin,
+				bool wps, const char *wpspin,
 				const char *error, void *user_data)
 {
 	struct connman_wispr_portal_context *wp_context = user_data;
 
 	DBG("");
 
-	if (error != NULL) {
+	if (error) {
 		if (g_strcmp0(error,
 			"net.connman.Agent.Error.LaunchBrowser") == 0) {
 			if (__connman_agent_request_browser(service,
@@ -608,7 +609,7 @@ static void wispr_portal_request_wispr_login(struct connman_service *service,
 	connman_wispr_message_init(&wp_context->wispr_msg);
 }
 
-static gboolean wispr_manage_message(GWebResult *result,
+static bool wispr_manage_message(GWebResult *result,
 			struct connman_wispr_portal_context *wp_context)
 {
 	DBG("Message type: %s (%d)",
@@ -618,21 +619,21 @@ static gboolean wispr_manage_message(GWebResult *result,
 		response_code_to_string(wp_context->wispr_msg.response_code),
 					wp_context->wispr_msg.response_code);
 
-	if (wp_context->wispr_msg.access_procedure != NULL)
+	if (wp_context->wispr_msg.access_procedure)
 		DBG("Access procedure: %s",
 			wp_context->wispr_msg.access_procedure);
-	if (wp_context->wispr_msg.access_location != NULL)
+	if (wp_context->wispr_msg.access_location)
 		DBG("Access location: %s",
 			wp_context->wispr_msg.access_location);
-	if (wp_context->wispr_msg.location_name != NULL)
+	if (wp_context->wispr_msg.location_name)
 		DBG("Location name: %s",
 			wp_context->wispr_msg.location_name);
-	if (wp_context->wispr_msg.login_url != NULL)
+	if (wp_context->wispr_msg.login_url)
 		DBG("Login URL: %s", wp_context->wispr_msg.login_url);
-	if (wp_context->wispr_msg.abort_login_url != NULL)
+	if (wp_context->wispr_msg.abort_login_url)
 		DBG("Abort login URL: %s",
 			wp_context->wispr_msg.abort_login_url);
-	if (wp_context->wispr_msg.logoff_url != NULL)
+	if (wp_context->wispr_msg.logoff_url)
 		DBG("Logoff URL: %s", wp_context->wispr_msg.logoff_url);
 
 	switch (wp_context->wispr_msg.message_type) {
@@ -663,7 +664,7 @@ static gboolean wispr_manage_message(GWebResult *result,
 
 			wispr_portal_request_portal(wp_context);
 
-			return TRUE;
+			return true;
 		} else
 			wispr_portal_error(wp_context);
 
@@ -672,10 +673,10 @@ static gboolean wispr_manage_message(GWebResult *result,
 		break;
 	}
 
-	return FALSE;
+	return false;
 }
 
-static gboolean wispr_portal_web_result(GWebResult *result, gpointer user_data)
+static bool wispr_portal_web_result(GWebResult *result, gpointer user_data)
 {
 	struct connman_wispr_portal_context *wp_context = user_data;
 	const char *redirect = NULL;
@@ -692,13 +693,13 @@ static gboolean wispr_portal_web_result(GWebResult *result, gpointer user_data)
 		if (length > 0) {
 			g_web_parser_feed_data(wp_context->wispr_parser,
 								chunk, length);
-			return TRUE;
+			return true;
 		}
 
 		g_web_parser_end_data(wp_context->wispr_parser);
 
 		if (wp_context->wispr_msg.message_type >= 0) {
-			if (wispr_manage_message(result, wp_context) == TRUE)
+			if (wispr_manage_message(result, wp_context))
 				goto done;
 		}
 	}
@@ -713,20 +714,19 @@ static gboolean wispr_portal_web_result(GWebResult *result, gpointer user_data)
 			break;
 
 		if (g_web_result_get_header(result, "X-ConnMan-Status",
-						&str) == TRUE) {
+						&str)) {
 			portal_manage_status(result, wp_context);
-			return FALSE;
-		}
-		else
+			return false;
+		} else
 			__connman_agent_request_browser(wp_context->service,
 					wispr_portal_browser_reply_cb,
 					wp_context->redirect_url, wp_context);
 
 		break;
 	case 302:
-		if (g_web_supports_tls() == FALSE ||
-				g_web_result_get_header(result, "Location",
-							&redirect) == FALSE) {
+		if (!g_web_supports_tls() ||
+			!g_web_result_get_header(result, "Location",
+							&redirect)) {
 
 			__connman_agent_request_browser(wp_context->service,
 					wispr_portal_browser_reply_cb,
@@ -749,7 +749,7 @@ static gboolean wispr_portal_web_result(GWebResult *result, gpointer user_data)
 						wp_context->type) == 0) {
 			wispr_portal_error(wp_context);
 			free_connman_wispr_portal_context(wp_context);
-			return FALSE;
+			return false;
 		}
 
 		break;
@@ -761,7 +761,7 @@ static gboolean wispr_portal_web_result(GWebResult *result, gpointer user_data)
 	wp_context->request_id = 0;
 done:
 	wp_context->wispr_msg.message_type = -1;
-	return FALSE;
+	return false;
 }
 
 static void proxy_callback(const char *proxy, void *user_data)
@@ -770,12 +770,12 @@ static void proxy_callback(const char *proxy, void *user_data)
 
 	DBG("proxy %s", proxy);
 
-	if (wp_context == NULL)
+	if (!wp_context)
 		return;
 
 	wp_context->token = 0;
 
-	if (proxy != NULL && g_strcmp0(proxy, "DIRECT") != 0)
+	if (proxy && g_strcmp0(proxy, "DIRECT") != 0)
 		g_web_set_proxy(wp_context->web, proxy);
 
 	g_web_set_accept(wp_context->web, NULL);
@@ -833,7 +833,7 @@ static int wispr_portal_detect(struct connman_wispr_portal_context *wp_context)
 	}
 
 	interface = connman_service_get_interface(wp_context->service);
-	if (interface == NULL)
+	if (!interface)
 		return -EINVAL;
 
 	DBG("interface %s", interface);
@@ -846,14 +846,14 @@ static int wispr_portal_detect(struct connman_wispr_portal_context *wp_context)
 	}
 
 	nameservers = connman_service_get_nameservers(wp_context->service);
-	if (nameservers == NULL) {
+	if (!nameservers) {
 		DBG("Could not get nameservers");
 		err = -EINVAL;
 		goto done;
 	}
 
 	wp_context->web = g_web_new(if_index);
-	if (wp_context->web == NULL) {
+	if (!wp_context->web) {
 		DBG("Could not set up GWeb");
 		err = -ENOMEM;
 		goto done;
@@ -870,7 +870,7 @@ static int wispr_portal_detect(struct connman_wispr_portal_context *wp_context)
 		wp_context->status_url = STATUS_URL_IPV6;
 	}
 
-	for (i = 0; nameservers[i] != NULL; i++)
+	for (i = 0; nameservers[i]; i++)
 		g_web_add_nameserver(wp_context->web, nameservers[i]);
 
 	proxy_method = connman_service_get_proxy_method(wp_context->service);
@@ -906,7 +906,7 @@ int __connman_wispr_start(struct connman_service *service,
 
 	DBG("service %p", service);
 
-	if (wispr_portal_list == NULL)
+	if (!wispr_portal_list)
 		return -EINVAL;
 
 	index = __connman_service_get_index(service);
@@ -915,9 +915,9 @@ int __connman_wispr_start(struct connman_service *service,
 
 	wispr_portal = g_hash_table_lookup(wispr_portal_list,
 					GINT_TO_POINTER(index));
-	if (wispr_portal == NULL) {
+	if (!wispr_portal) {
 		wispr_portal = g_try_new0(struct connman_wispr_portal, 1);
-		if (wispr_portal == NULL)
+		if (!wispr_portal)
 			return -ENOMEM;
 
 		g_hash_table_replace(wispr_portal_list,
@@ -932,11 +932,11 @@ int __connman_wispr_start(struct connman_service *service,
 		return -EINVAL;
 
 	/* If there is already an existing context, we wipe it */
-	if (wp_context != NULL)
+	if (wp_context)
 		free_connman_wispr_portal_context(wp_context);
 
 	wp_context = create_wispr_portal_context();
-	if (wp_context == NULL)
+	if (!wp_context)
 		return -ENOMEM;
 
 	wp_context->service = service;
@@ -957,7 +957,7 @@ void __connman_wispr_stop(struct connman_service *service)
 
 	DBG("service %p", service);
 
-	if (wispr_portal_list == NULL)
+	if (!wispr_portal_list)
 		return;
 
 	index = __connman_service_get_index(service);
